==> apek-0.0.2b1.tar.gz: apek-0.0.2b1/README.md <==
# apek Package

## Introduction
`apek` is a Python package for handling large numbers. It represents large numbers using scientific notation `XeY` and provides rich functionalities to support operations and formatted display of large numbers.

## Features
- **Large Number Representation**: Represents large numbers using scientific notation through the `LargeNumber` class.
- **Precision Control**: Supports setting display precision and actual calculation precision.
- **Customizable Unit Tables**: Allows customization of English and Chinese unit tables for formatted display of large numbers.
- **Language Support**: Provides language setting functionality for help information, supporting English and Chinese.
- **Version Log**: Offers the ability to view version update logs.

## Installation
Install via pip:
```bash
pip install apek==0.0.2b1
```

## Usage

### LargeNumber Class

```python
from apek import LargeNumber

# Create a LargeNumber instance
num = LargeNumber(1.2345, 6)  # Represents 1.2345e6

# Set precision and unit table
num = LargeNumber(1.2345, 6, displayPrecision=2, reprUnitTable="KMBT")
print(num.parseString())  # Output the formatted string

# Operations
num1 = LargeNumber(1.2, 3)
num2 = LargeNumber(2.3, 4)
result = num1 + num2
print(result)  # Output the result of the operation
```

### Help Function

```python
from apek import helps

# Set language
helps.language("en")  # Set to English
helps.language("zh")  # Set to Chinese

# View version update log
helps.upgradeLog("0.0.1")  # View the log for a specific version
```

## Example

```python
# Create a large number and perform operations
num1 = LargeNumber(1.2345, 10)
num2 = LargeNumber(6.789, 5)
result = num1 * num2
print(result.parseString(largeExpRepr="byUnit"))  # Output using unit table formatting
```

## Upgraded Contents
- When setting the language through the `helps` module, if the language is not supported, it will list all the currently supported languages.
- Fixed the error in the module description.

## Version Information
- Current Version: 0.0.2b1
- Previous Version: 0.0.1a3

(Translated by Kimi)


***


# apek 包

## 简介
`apek` 是一个用于处理大数字的 Python 包。它通过科学记数法 `XeY` 来表示大数字，并提供了丰富的功能来支持大数字的运算和格式化显示。

## 功能
- **大数字表示**：通过 `LargeNumber` 类，使用科学记数法表示大数字。
- **精度控制**：支持设置显示精度和实际计算精度。
- **单位表自定义**：可以自定义英文单位表和中文单位表，用于大数字的格式化显示。
- **语言支持**：提供帮助信息的语言设置功能，支持英文和中文。
- **版本日志**：提供版本更新日志的查看功能。

## 安装
通过 pip 安装：
```bash
pip install apek
```

## 使用方法

### LargeNumber 类

```python
from apek import LargeNumber

# 创建 LargeNumber 实例
num = LargeNumber(1.2345, 6)  # 表示 1.2345e6

# 设置精度和单位表
num = LargeNumber(1.2345, 6, displayPrecision=2, reprUnitTable="KMBT")
print(num.parseString())  # 输出格式化后的字符串

# 运算
num1 = LargeNumber(1.2, 3)
num2 = LargeNumber(2.3, 4)
result = num1 + num2
print(result)  # 输出运算结果
```

### 帮助功能

```python
from apek import helps

# 设置语言
helps.language("en")  # 设置为英文
helps.language("zh")  # 设置为中文

# 查看版本更新日志
helps.upgradeLog("0.0.1")  # 查看指定版本的日志
```

## 示例

```python
# 创建一个大数字并进行运算
num1 = LargeNumber(1.2345, 10)
num2 = LargeNumber(6.789, 5)
result = num1 * num2
print(result.parseString(largeExpRepr="byUnit"))  # 使用单位表格式化输出
```

## 更新内容
- 通过 `helps` 模块设置语言时，如果语言不支持，会列出所有当前支持的语言。
- 修复了模块描述的错误。

## 版本信息
- 当前版本：0.0.2b1
- 上一版本：0.0.1a3

(Write by Kimi)

==> apek-0.0.3a11.tar.gz: apek-0.0.3a11/README.md <==
# Introduction
`apek` is a Python package for handling large numbers. It represents large numbers using scientific notation `XeY` and provides rich functionalities to support operations and formatted display of large numbers.

# Features
- **Large Number Representation**: Represents large numbers using scientific notation through the `LargeNumber` class.
- **Precision Control**: Supports setting display precision and actual calculation precision.
- **Customizable Unit Tables**: Allows customization of English and Chinese unit tables for formatted display of large numbers.
- **Language Support**: Provides language setting functionality for help information, supporting English and Chinese.
- **Version Log**: Offers the ability to view version update logs.

# Installation
Install via pip:
```bash
pip install apek==0.0.3a11
```

# Usage

## LargeNumber Class

```python
from apek import LargeNumber

# Create a LargeNumber instance
num = LargeNumber(1.2345, 6)  # Represents 1.2345e6

# Set precision and unit table
num = LargeNumber(1.2345, 6, dispPrec=2, reprUnits_en="KMBT")
print(num.parseString())  # Output the formatted string

# Operations
num1 = LargeNumber(1.2, 3)
num2 = LargeNumber(2.3, 4)
result = num1 + num2
print(result)  # Output the result of the operation
```

## Help Function

```python
from apek import helps

# Set language
helps.language("en")  # Set to English
helps.language("zh")  # Set to Chinese

# View version update log
helps.upgradeLog("0.0.1")  # View the log for a specific version
```

## Example

```python
# Create a large number and perform operations
num1 = LargeNumber(1.2345, 10)
num2 = LargeNumber(6.789, 5)
result = num1 * num2
print(result.parseString(expReprMode="byUnit"))  # Output using unit table formatting
```

# Upgraded Contents
- Removed a meaningless `pass` statement.
- Modified the `__bool__` method.
- Improved type checking.
- Fixed some errors.

(Translated by Kimi)


***


# apek 包

# 简介
`apek`是一个用于处理大数字的Python包。它通过科学记数法"XeY"来表示大数字，并提供了一些功能来支持大数字的运算和格式化显示。

# 功能
- **大数字表示**：通过`LargeNumber`类，使用科学记数法表示大数字。
- **精度控制**：支持设置显示精度和实际计算精度。
- **单位表自定义**：可以自定义英文单位表和中文单位表，用于大数字的格式化显示。
- **语言支持**：提供帮助信息的语言设置功能，支持英文和中文。
- **版本日志**：提供版本更新日志的查看功能。

# 安装
通过 pip 安装：
```bash
pip install apek==0.0.3a11
```

# 使用方法

## LargeNumber 类

```python
from apek import LargeNumber

# 创建LargeNumber实例
num = LargeNumber(1.2345, 6)  # 表示1.2345e6

# 设置精度和单位表
num = LargeNumber(1.2345, 6, dispPrec=2, reprUnits_en="KMBT")
print(num.parseString())  # 输出格式化后的字符串

# 运算
num1 = LargeNumber(1.2, 3)
num2 = LargeNumber(2.3, 4)
result = num1 + num2
print(result)  # 输出运算结果
```

## 帮助功能

```python
from apek import helps

# 设置语言
helps.language("en")  # 设置为英文
helps.language("zh")  # 设置为中文

# 查看版本更新日志
helps.upgradeLog("0.0.1")  # 查看指定版本的日志
```

## 示例

```python
# 创建一个大数字并进行运算
num1 = LargeNumber(1.2345, 10)
num2 = LargeNumber(6.789, 5)
result = num1 * num2
print(result.parseString(expReprMode="byUnit"))  # 使用单位表格式化输出
```

# 更新内容
- 移除了一个无意义的`pass`语句。
- 修改了`__bool__`方法。
- 完善了类型检查。
- 修复了一些错误。

(Write by Kimi)
